@@ -28,8 +28,17 @@
 #' and `lambda` arguments.
 #' 
 #' @param params A MizerParams object
-#' @param resource_rate Optional. Vector of resource intrinsic birth rates
-#' @param resource_capacity Optional. Vector of resource intrinsic carrying capacity
+#' @param resource_rate Optional. Vector of resource intrinsic birth rates 
+#' @param comment_rate `r lifecycle::badge("experimental")`
+#'   A string describing how the value for 'resource_rate' was obtained. This is
+#'   ignored if 'resource_rate' is not supplied or already has a comment
+#'   attribute.
+#' @param resource_capacity Optional. Vector of resource intrinsic carrying 
+#'   capacity 
+#' @param comment_capacity `r lifecycle::badge("experimental")`
+#'   A string describing how the value for 'resource_capacity' was obtained. This is
+#'   ignored if 'resource_capacity' is not supplied or already has a comment
+#'   attribute.
 #' @param r_pp Coefficient of the intrinsic resource birth rate
 #' @param n Allometric growth exponent for resource
 #' @param kappa Coefficient of the intrinsic resource carrying capacity
@@ -52,7 +61,9 @@
 #' @family functions for setting parameters
 setResource <- function(params,
                         resource_rate = NULL,
+                        comment_rate = "set manually",
                         resource_capacity = NULL,
+                        comment_capacity = "set manually",
                         r_pp = resource_params(params)[["r_pp"]],
                         kappa = resource_params(params)[["kappa"]],
                         lambda = resource_params(params)[["lambda"]],
@@ -73,6 +84,9 @@ setResource <- function(params,
     params@resource_params[["w_pp_cutoff"]] <- w_pp_cutoff
     # weight specific resource growth rate
     if (!is.null(resource_rate)) {
+        if (is.null(comment(resource_rate))) {
+            comment(resource_rate) <- comment_rate
+        }
         assert_that(is.numeric(resource_rate),
                     identical(length(resource_rate), length(params@rr_pp)))
         params@rr_pp[] <- resource_rate
@@ -80,8 +94,7 @@ setResource <- function(params,
     } else {
         rr_pp <- r_pp * params@w_full^(n - 1)
         if (!is.null(comment(params@rr_pp)) &&
-            !isTRUE(all.equal(params@rr_pp, rr_pp,
-                          check.attributes = FALSE))) {
+            different(params@rr_pp, rr_pp)) {
             message("The resource intrinsic growth rate has been commented and therefore will ",
                     "not be recalculated from the resource parameters.")
         } else {
@@ -90,6 +103,9 @@ setResource <- function(params,
     }
     # the resource carrying capacity
     if (!is.null(resource_capacity)) {
+        if (is.null(comment(resource_capacity))) {
+            comment(resource_capacity) <- comment_capacity
+        }
         assert_that(is.numeric(resource_capacity),
                     identical(length(resource_capacity), length(params@cc_pp)))
         params@cc_pp[] <- resource_capacity
@@ -98,8 +114,7 @@ setResource <- function(params,
         cc_pp <- kappa*params@w_full^(-lambda)
         cc_pp[params@w_full > w_pp_cutoff] <- 0
         if (!is.null(comment(params@cc_pp)) &&
-            !isTRUE(all.equal(params@cc_pp, cc_pp,
-                              check.attributes = FALSE))) {
+            different(params@cc_pp, cc_pp)) {
             message("The resource carrying capacity has been commented and therefore will ",
                     "not be recalculated from the resource parameters.")
         } else {
